@@ -38,22 +38,24 @@ class KDesktopFile;
 class MenuFile;
 class MenuFolderInfo;
 class MenuEntryInfo;
+class MenuSeparatorInfo;
 class KShortcut;
 
-static const QString SAVE_ACTION_NAME = "file_save";
-static const QString NEW_ITEM_ACTION_NAME = "new_item";
-static const QString NEW_SUBMENU_ACTION_NAME = "new_submenu";
-static const QString CUT_ACTION_NAME = "edit_cut";
-static const QString COPY_ACTION_NAME = "edit_copy";
-static const QString PASTE_ACTION_NAME = "edit_paste";
-static const QString DELETE_ACTION_NAME = "delete";
-static const QString SORT_ACTION_NAME = "sort";
-static const QString SORT_BY_NAME_ACTION_NAME = "sort_by_name";
-static const QString SORT_BY_DESCRIPTION_ACTION_NAME = "sort_by_description";
-static const QString SORT_ALL_BY_NAME_ACTION_NAME = "sort_all_by_name";
-static const QString SORT_ALL_BY_DESCRIPTION_ACTION_NAME = "sort_all_by_description";
-static const QString MOVE_UP_ACTION_NAME = "move_up";
-static const QString MOVE_DOWN_ACTION_NAME = "move_down";
+static const QString SAVE_ACTION_NAME = QStringLiteral("file_save");
+static const QString NEW_ITEM_ACTION_NAME = QStringLiteral("new_item");
+static const QString NEW_SUBMENU_ACTION_NAME = QStringLiteral("new_submenu");
+static const QString NEW_SEPARATOR_ACTION_NAME = QStringLiteral("new_separator");
+static const QString CUT_ACTION_NAME = QStringLiteral("edit_cut");
+static const QString COPY_ACTION_NAME = QStringLiteral("edit_copy");
+static const QString PASTE_ACTION_NAME = QStringLiteral("edit_paste");
+static const QString DELETE_ACTION_NAME = QStringLiteral("delete");
+static const QString SORT_ACTION_NAME = QStringLiteral("sort");
+static const QString SORT_BY_NAME_ACTION_NAME = QStringLiteral("sort_by_name");
+static const QString SORT_BY_DESCRIPTION_ACTION_NAME = QStringLiteral("sort_by_description");
+static const QString SORT_ALL_BY_NAME_ACTION_NAME = QStringLiteral("sort_all_by_name");
+static const QString SORT_ALL_BY_DESCRIPTION_ACTION_NAME = QStringLiteral("sort_all_by_description");
+static const QString MOVE_UP_ACTION_NAME = QStringLiteral("move_up");
+static const QString MOVE_DOWN_ACTION_NAME = QStringLiteral("move_down");
 
 class TreeItem : public QTreeWidgetItem
 {
@@ -82,6 +84,7 @@ public:
 
     bool isDirectory() const { return m_folderInfo; }
     bool isEntry() const { return m_entryInfo; }
+    bool isSeparator() const { return !isDirectory() && !isEntry(); }
 
     bool isHiddenInMenu() const { return m_hidden; }
     void setHiddenInMenu(bool b);
@@ -144,6 +147,7 @@ protected Q_SLOTS:
 
     void newsubmenu();
     void newitem();
+    void newsep();
 
     void cut();
     void copy();
@@ -167,6 +171,7 @@ protected:
     QTreeWidgetItem *selectedItem();
     TreeItem *createTreeItem(TreeItem *parent, QTreeWidgetItem *after, MenuFolderInfo *folderInfo, bool _init = false);
     TreeItem *createTreeItem(TreeItem *parent, QTreeWidgetItem *after, MenuEntryInfo *entryInfo, bool _init = false);
+    TreeItem *createTreeItem(TreeItem *parent, QTreeWidgetItem *after, MenuSeparatorInfo *sepInfo, bool _init = false);
 
     void del(TreeItem *, bool deleteInfo);
     void fill();
@@ -207,6 +212,7 @@ private:
     bool               m_showHidden;
     MenuFile          *m_menuFile;
     MenuFolderInfo    *m_rootFolder;
+    MenuSeparatorInfo *m_separator;
     QStringList        m_newMenuIds;
     QStringList        m_newDirectoryList;
     bool               m_layoutDirty;
